@@ -1,3 +1,5 @@
+import typing
+
 import click
 import httpx
 import typer
@@ -77,47 +79,21 @@ def _update_profile(
     return profile
 
 
-def _basic_login(
-    ctx: typer.Context,
-):
-    email = typer.prompt(
-        "[{profile}] Enter email".format(
-            profile=ctx.obj.profile_name,
-        ),
-    )
-
-    r = httpx.post(
-        "{auth_url}/login".format(auth_url=auth_url(ctx.obj.get_gateway_api_url())),
-        json={"email": email},
-    )
-
-    if not is_success_response(r):
-        process_response(r)
-
-    upsert_config(ctx, _update_profile(ctx, schema.Auth(access_token=r.json()["token"], refresh_token="")))
-
-    send_output(
-        msg="Login success",
-        exit_code=0,
-    )
-
-
 @app.command()
 def login(
     ctx: typer.Context,
+    password: typing.Optional[str] = typer.Option(None, "--password", "-p"),
 ):
     check_profile_exists(ctx)
 
-    if ctx.obj.profile.auth_flow == constant.AuthFlow.basic.value:
-        return _basic_login(ctx)
-
-    password = typer.prompt(
-        "[{profile}] Enter password for user ({user})".format(
-            profile=ctx.obj.profile_name,
-            user=ctx.obj.profile.user,
-        ),
-        hide_input=True,
-    )
+    if password is None:
+        password = typer.prompt(
+            "[{profile}] Enter password for user ({user})".format(
+                profile=ctx.obj.profile_name,
+                user=ctx.obj.profile.user,
+            ),
+            hide_input=True,
+        )
 
     r = httpx.post(
         "{auth_url}/login".format(auth_url=auth_url(ctx.obj.get_gateway_api_url())),
@@ -139,14 +115,6 @@ def login(
 def logout(ctx: typer.Context):
     check_profile_exists(ctx)
 
-    if ctx.obj.profile.auth_flow == constant.AuthFlow.basic.value:
-        upsert_config(ctx, _update_profile(ctx, schema.Auth()))
-
-        send_output(
-            msg="Logout success",
-            exit_code=0,
-        )
-
     _check_refresh_token_exists(ctx)
 
     r = httpx.post(
