@@ -1,10 +1,10 @@
 import configparser
 import dataclasses
-import typing
 from enum import Enum
 from typing import Any
 from typing import Dict
 from typing import List
+from typing import Optional
 
 from pydantic import BaseModel
 
@@ -18,7 +18,7 @@ class FieldDataType(BaseModel):
 
 class FieldDefinition(BaseModel):
     name: str
-    description: str | None = None
+    description: Optional[str] = None
     type: str
     primary: bool
     optional: bool
@@ -41,9 +41,9 @@ class RemoveCore(BaseModel):
 
 class Auth(BaseModel):
     access_token: str = ""
-    expires_in: int | None = None
+    expires_in: Optional[int] = None
     refresh_token: str = ""
-    refresh_expires_in: int | None = None
+    refresh_expires_in: Optional[int] = None
 
 
 class OptionalProfile(BaseModel):
@@ -79,10 +79,10 @@ class EffectEnum(Enum):
 
 class Statement(BaseModel):
     sid: str
-    principal: typing.List[str]
-    action: typing.List[str]
-    resource: typing.List[str]
-    condition: typing.List[str] | None = None
+    principal: List[str]
+    action: List[str]
+    resource: List[str]
+    condition: Optional[List[str]] = None
     effect: EffectEnum = EffectEnum.allow
 
     class Config:
@@ -90,12 +90,12 @@ class Statement(BaseModel):
 
 
 class Statements(BaseModel):
-    statements: typing.List[Statement]
+    statements: List[Statement]
 
 
 class Policy(BaseModel):
     version: str = "2022-10-01"
-    statements: list[Statement]
+    statements: List[Statement]
 
 
 class UserPolicy(BaseModel):
@@ -110,7 +110,7 @@ class Common:
     iam_api_url: str
     profile_name: str
     config: configparser.ConfigParser
-    profile: Profile | None
+    profile: Optional[Profile]
 
     def get_gateway_api_url(self):
         url = None
