@@ -92,7 +92,7 @@ def get_user_profile(c: configparser.ConfigParser, profile_name: str, allow_miss
         return get_schema_profile(profile_name, allow_missing=allow_missing, **profile_config)
 
 
-def bearer(ctx: typer.Context) -> typing.Dict | None:
+def bearer(ctx: typer.Context) -> typing.Optional[typing.Dict]:
     if not (ctx.obj.profile and ctx.obj.profile.access_token != ""):
         return None
 
